*********************************************************************
* matrix of transformatiom of vector from S/C system to GSE system:
*                   Vs/c = pa*Vgse
*
* input:  x(1,..12), z(1,2) - attitude coefficients data set for the
*         diven time interval corresponding to a line in attitude
*         coefficients array;
*
*         ts - time relative of beginning of the data interval
*             (in thousands if sec);
*
* output: pa(3x3) - matrix of transformation.
*
*********************************************************************
      subroutine attidf(ts,pa)
      common /z/ z(2)
      common /c/ x(12)
      dimension s(3),e(3),p2(3),pa(3,3)
      rgr = atan(1.)/45
*
* alpha, beta angles
      alf=x(1)+x(2)*sin(x(11)*ts)+x(3)*cos(x(11)*ts)+x(4)*sin(x(12)*ts)+
     *x(5)*cos(x(12)*ts)
      bet=x(6)+x(7)*sin(x(11)*ts)+x(8)*cos(x(11)*ts)+x(9)*sin(x(12)*ts)+
     *x(10)*cos(x(12)*ts)
*
* direction to the Sun
      al =alf*rgr
      tga=tan(al)
      be =bet*rgr
      tgb=tan(be)
      s(1)=1./sqrt(1.+tga**2+tgb**2)
      s(2)=tga * s(1)
      s(3)=tgb * s(1)
*
* gamma angle
      g=z(1) + z(2)*ts
*
* direction to the Ecliptic Pole
      ax=s(2)*cos(g) + s(3)*sin(g)
      e(1)= -ax/sqrt(ax**2+s(1)**2)
      e(2)= sqrt(1.-e(1)**2)*cos(g)
      e(3)= sqrt(1.-e(1)**2)*sin(g)
*
* the third direction p2=e x p2
      call vect (e,s,p2)
*
*  matrix of transformation
          do 1 i=1,3
          pa(1,i)=  S(i)
          pa(2,i)= p2(i)
    1     pa(3,i)=  e(i)
*
      return
      end
*
      subroutine vect(x,y,z)
      dimension x(3),y(3),z(3)
      z(1)=x(2)*y(3)-y(2)*x(3)
      z(2)=x(3)*y(1)-x(1)*y(3)
      z(3)=x(1)*y(2)-x(2)*y(1)
      zz=sqrt(z(1)**2+z(2)**2+z(3)**2)
      do 1 i=1,3
    1 z(i)=z(i)/zz
      return
      end
